@@ -15,8 +15,9 @@ formulaToQuery <- function(formula, data) {
         halt(dQuote("formula"), " is not a valid formula")
     }
 
-    vars <- parseTerms(formula, data, side = "RHS")
-    measures <- parseTerms(formula, data, side = "LHS")
+    parsed_terms <- parseTerms(formula, data)
+    vars <- parsed_terms$RHS
+    measures <- parsed_terms$LHS
 
     ## Construct the "measures", either from the formula or default "count"
     if (!length(measures)) {
@@ -61,7 +62,7 @@ formulaToQuery <- function(formula, data) {
     return(list(dimensions = dimensions, measures = measures))
 }
 
-parseTerms <- function(formula, data, side = "RHS") {
+parseTerms <- function(formula, data) {
     terms <- terms(formula, allowDotAsName = TRUE)
     f.vars <- attr(terms, "variables")
     all.f.vars <- all.vars(f.vars)
@@ -101,18 +102,15 @@ parseTerms <- function(formula, data, side = "RHS") {
     }
 
     resp <- attr(terms, "response")
-    if (side == "RHS") {
-        if (resp > 0) {
-            # remove response vars only if there are any
-            vars <- vars[-resp]
-        }
-    } else if (side == "LHS") {
-        vars <- vars[resp]
+    if (resp > 0) {
+        # remove response vars only if there are any
+        RHS <- vars[-resp]
     } else {
-        halt("unknown side specification for parsing formulae.")
+        RHS <- vars
     }
+    LHS <- vars[resp]
 
-    return(vars)
+    return(list(LHS = LHS, RHS = RHS))
 }
 
 registerCubeFunctions <- function(varnames = c()) {
@@ -125,12 +123,18 @@ registerCubeFunctions <- function(varnames = c()) {
     numfunc <- function(func, ...) {
         force(func)
         moreArgs <- list(...)
-        return(function(x) {
+        return(function(x, ...) {
             if (is.Categorical(x)) {
                 ## "Cast" it on the fly
                 x <- list(zfunc("cast", x, "numeric"))
             }
-            do.call("zfunc", c(func, x, moreArgs))
+            dots <- list(...)
+            if ("na.rm" %in% names(dots)) {
+                # --- Translate R's `na.rm` to zz9's `ignore_missing`
+                dots[["ignore_missing"]] <- list(value = dots[["na.rm"]])
+                dots[["na.rm"]] <- NULL
+            }
+            do.call("zfunc", c(func, x, moreArgs, dots))
             # zfunc(func, x)
         })
     }
@@ -214,9 +218,9 @@ getCubeMeasureNames <- function(measures) {
 }
 
 isCubeAggregation <- function(x) {
-    length(names(x)) == 2L &&
-        setequal(names(x), c("function", "args")) &&
-        grepl("^cube_", x[["function"]])
+    # --- Must have function and args and possibly kwargs, but nothing else
+    allowed <- c("function", "args", "kwargs")
+    length(setdiff(names(x), allowed)) == 0 && grepl("^cube_", x[["function"]])
 }
 
 is.zfunc <- function(x, func) {
