@@ -98,35 +98,6 @@ expect_valid_apidocs_import <- function(ds) {
     )
 }
 
-expect_either <- function(func, object, new, old, ...) {
-    # Try the test with the new exepctation, if that doesn't work, try the old.
-    # Only fail if the old does not work.
-    # func is a testthat function (like expect_equal)
-    # object is the object to be compared
-    # new is the new expectation
-    # old is the old expectation
-    tryCatch(
-        func(object, old, ...),
-        error = function(e) {
-            # if we hit new, be verbose printing the call's grandparent so that
-            # we know we probably should remove the expect_either
-            call <- sys.call(sys.parent(4))
-            msg <- paste0(
-                "\n",
-                "The following test call is using the new expectation, ",
-                "expect_either should probably be removed:",
-                "\n",
-                capture.output(call),
-                "\n"
-            )
-
-            func(object, new, ...)
-
-            # if the test passes, then display the message to remove.
-            cat(msg)
-        })
-}
-
 expect_identical_temp_nodata <- function(actual, expected) {
     # Newer versions of the Crunch API will automatically add a "No Data"
     # category if not present. This helper transitions us to that future, and
