@@ -66,7 +66,7 @@ test_that("print compareCategory summary when categories are equivalent", {
 
 with_mock_crunch({
     ds1 <- cachedLoadDataset("test ds")
-    ds2 <- loadDataset("an archived dataset", "archived")
+    ds2 <- loadDataset("2", "archived", project = NULL)
 
     test_that("compareVariables", {
         expect_equal(
