@@ -696,7 +696,7 @@ if (tolower(Sys.info()[["sysname"]]) != "windows") {
         )
 
         # malform the transform for animals only
-        pet_feeling_bad_feelings@dims$feelings$references$view$transform$insertions[[2]]$anchor <- NA
+        pet_feeling_bad_feelings@dims$feelings$references$view$transform$insertions[[2]]$anchor <- NA # nolint
         expect_warning(
             expect_equivalent(applyTransforms(pet_feeling_bad_feelings), only_feelings),
             "Transforms for dimensions 1 were malformed and have been ignored."
@@ -815,8 +815,8 @@ if (tolower(Sys.info()[["sysname"]]) != "windows") {
         all <- cubify(
             7.09439811221956, 29.943091432266, 26.594536972556, 104.244359622909, 235.256710642724,
             28.3930651341193, 99.907133775628, 121.487888771867, 399.597650747672, 626.93247871747,
-            16.4723263871271, 41.5273628588211, 58.5641962784524, 183.864543659439, 234.846288302351,
-            4.82634063477261, 28.4366794845409, 36.3291555208591, 111.488747465324, 156.829479772395,
+            16.4723263871271, 41.5273628588211, 58.5641962784524, 183.864543659439, 234.846288302351, # nolint
+            4.82634063477261, 28.4366794845409, 36.3291555208591, 111.488747465324, 156.829479772395, # nolint
             12.217223612475, 42.1476791820657, 89.3309048228944, 218.631137785724, 171.129707467715,
             12.217223612475, 42.1476791820657, 89.3309048228944, 218.631137785724, 171.129707467715,
             dims = cat_mr_dims_subtotals
@@ -832,12 +832,12 @@ if (tolower(Sys.info()[["sysname"]]) != "windows") {
 
     test_that("cat by mr, with cat subtotals (margins and proportions)", {
         row_margin <- cubify(
-            51.911366492838, 69.0306061146165, 70.6657653721693, 142.042366487671, 253.602877279968,
-            197.750644752234, 263.820951392254, 276.216370215392, 509.242733468184, 726.557193538396,
-            93.7790931477866, 121.118408249056, 130.06549190286, 231.730645711963, 279.991871527124,
-            52.0601851116097, 73.6719370285819, 75.4851129403625, 135.46972126855, 192.962444731304,
-            70.2849657255216, 94.3678915294494, 135.475226421184, 251.200447977195, 215.124923979429,
-            70.2849657255216, 94.3678915294494, 135.475226421184, 251.200447977195, 215.124923979429,
+            51.911366492838, 69.0306061146165, 70.6657653721693, 142.042366487671, 253.602877279968, # nolint
+            197.750644752234, 263.820951392254, 276.216370215392, 509.242733468184, 726.557193538396, # nolint
+            93.7790931477866, 121.118408249056, 130.06549190286, 231.730645711963, 279.991871527124, # nolint
+            52.0601851116097, 73.6719370285819, 75.4851129403625, 135.46972126855, 192.962444731304, # nolint
+            70.2849657255216, 94.3678915294494, 135.475226421184, 251.200447977195, 215.124923979429, # nolint
+            70.2849657255216, 94.3678915294494, 135.475226421184, 251.200447977195, 215.124923979429, # nolint
             dims = cat_mr_dims_subtotals
         )
         expect_equivalent(as.array(margin.table(cat_mr, 1)), row_margin)
