@@ -24,13 +24,14 @@ test_that("newDataset input validation", {
     )
 })
 
+project_url <- "https://app.crunch.io/api/projects/abc"
 with_mock_crunch({
     test_that("Basic exercise of turning data.frame to Crunch payload", {
         expect_POST(
-            newDataset(data.frame(a = 1), name = "Testing"),
+            newDataset(data.frame(a = 1), name = "Testing", project = project_url),
             "https://app.crunch.io/api/datasets/",
-            '{"element":"shoji:entity","body":{"name":"Testing",',
-            '"table":{"element":"crunch:table",',
+            '{"element":"shoji:entity","body":{"name":"Testing","project":"',
+            project_url, '","table":{"element":"crunch:table",',
             '"metadata":{"a":{"type":"numeric","name":"a","alias":"a"}},',
             '"order":["a"]}}}'
         )
@@ -38,10 +39,10 @@ with_mock_crunch({
 
     test_that("Turning data.frame to Crunch payload without a name", {
         expect_POST(
-            newDataset(data.frame(a = 1)),
+            newDataset(data.frame(a = 1), project = project_url),
             "https://app.crunch.io/api/datasets/",
             '{"element":"shoji:entity","body":{"name":"data.frame(a = 1)",',
-            '"table":{"element":"crunch:table",',
+            '"project":"', project_url, '","table":{"element":"crunch:table",',
             '"metadata":{"a":{"type":"numeric","name":"a","alias":"a"}},',
             '"order":["a"]}}}'
         )
@@ -49,10 +50,11 @@ with_mock_crunch({
 
     test_that("Turning data.frame to Crunch payload with a long name", {
         expect_POST(
-            newDataset(data.frame(a = 1, really_really_long_name = 2)),
+            newDataset(data.frame(a = 1, really_really_long_name = 2), project = project_url),
             "https://app.crunch.io/api/datasets/",
             '{"element":"shoji:entity","body":{"name":"data.frame(a = 1, ',
-            'really_really_long_nam","table":{"element":"crunch:table",',
+            'really_really_long_nam","project":"', project_url,
+            '","table":{"element":"crunch:table",',
             '"metadata":{"a":{"type":"numeric","name":"a","alias":"a"},',
             '"really_really_long_name":{"type":"numeric",',
             '"name":"really_really_long_name","alias":"really_really_long_name"}},',
@@ -74,30 +76,31 @@ with_mock_crunch({
 
     test_that("createDataset with named args", {
         expect_POST(
-            createDataset(name = "Foo", description = "Bar."),
+            createDataset(name = "Foo", description = "Bar.", project = project_url),
             "https://app.crunch.io/api/datasets/",
             '{"element":"shoji:entity","body":{"name":"Foo",',
-            '"description":"Bar."}}'
+            '"description":"Bar.","project":"', project_url, '"}}'
         )
     })
     test_that("createDataset returns a dataset", {
         with_POST(
             "https://app.crunch.io/api/datasets/1/",
-            expect_true(is.dataset(createDataset(name = "Foo")))
+            expect_true(is.dataset(createDataset(name = "Foo", project = project_url)))
         )
     })
     test_that("newDataset calls newDatasetFromFile if given a string", {
         expect_POST(
-            newDataset("helper.R"),
+            newDataset("helper.R", project = project_url),
             "https://app.crunch.io/api/datasets/",
-            '{"element":"shoji:entity","body":{"name":"helper.R"}}'
+            '{"element":"shoji:entity","body":{"name":"helper.R","project":"',
+            project_url, '"}}'
         )
     })
     test_that("newDataset with an .sss schema posts to sources", {
         temp_file <- tempfile("schema", fileext = ".sss")
         file.create(temp_file)
         expect_POST(
-            newDataset(x = "helper.R", schema = temp_file),
+            newDataset(x = "helper.R", schema = temp_file, project = project_url),
             "https://app.crunch.io/api/sources/",
             paste0("list\\(uploaded_file = list\\(path = .*", basename(temp_file)),
             fixed = FALSE
@@ -107,7 +110,7 @@ with_mock_crunch({
         temp_file <- tempfile("schema", fileext = ".xml")
         file.create(temp_file)
         expect_POST(
-            newDataset(x = "helper.R", schema = temp_file),
+            newDataset(x = "helper.R", schema = temp_file, project = project_url),
             "https://app.crunch.io/api/sources/",
             paste0("list\\(uploaded_file = list\\(path = .*", basename(temp_file)),
             fixed = FALSE
@@ -115,7 +118,7 @@ with_mock_crunch({
     })
     test_that("newDataset with a .json schema posts to datasets", {
         path_json <- system.file("example-datasets", "pets.json", package = "crunch")
-        content_json <- readLines(path_json)
+        content_json <- jsonlite::minify(readLines(path_json))
         expect_POST(
             newDataset(x = "helper.R", schema = path_json),
             "https://app.crunch.io/api/datasets/",
@@ -128,7 +131,7 @@ with_mock_crunch({
             1
         )
         expect_error(
-            newDataset(x = "helper.R", schema = paste0("schema.", unsupported_format)),
+            newDataset(x = "helper.R", schema = paste0("schema.", unsupported_format), project = project_url),
             "Unsupported schema type:"
         )
     })
@@ -138,18 +141,18 @@ with_mock_crunch({
             # we supressMessages which makes detecting it harder
             temp_file <- tempfile("schema", fileext = ".sss")
             file.create(temp_file)
-            ds <- newDataset(x = "teardown.R", schema = temp_file)
+            ds <- newDataset(x = "teardown.R", schema = temp_file, project = project_url)
         })
     })
     test_that("newDataset(FromFile) cleans up the dataset entity if the file is invalid", {
         with_POST("https://app.crunch.io/api/datasets/1/", {
             expect_DELETE(
-                newDataset("NOTAFILE.exe"),
+                newDataset("NOTAFILE.exe", project = project_url),
                 "https://app.crunch.io/api/datasets/1/"
             )
             with_DELETE(NULL, {
                 expect_error(
-                    newDataset("NOTAFILE.exe"),
+                    newDataset("NOTAFILE.exe", project = project_url),
                     "File not found"
                 )
             })
@@ -158,7 +161,7 @@ with_mock_crunch({
     test_that("newDataset(FromFile) can take an s3 URL", {
         with_DELETE(NULL, {
             expect_POST(
-                newDataset("s3://httpbin.org/get"),
+                newDataset("s3://httpbin.org/get", project = project_url),
                 "https://app.crunch.io/api/datasets/1/batches/",
                 '{"element":"shoji:entity",',
                 '"body":{"url":"s3://httpbin.org/get"}}'
@@ -168,7 +171,7 @@ with_mock_crunch({
     test_that("newDataset(FromFile) can take an http(s) URL", {
         with_DELETE(NULL, {
             expect_POST(
-                newDataset("https://httpbin.org/get"),
+                newDataset("https://httpbin.org/get", project = project_url),
                 "https://app.crunch.io/api/sources/",
                 '{"element":"shoji:entity",',
                 '"body":{"location":"https://httpbin.org/get"}}'
@@ -178,9 +181,9 @@ with_mock_crunch({
 
     test_that("newDatasetByColumn", {
         expect_POST(
-            newDatasetByColumn(data.frame(a = 1), name = "Bam!"),
+            newDatasetByColumn(data.frame(a = 1), name = "Bam!", project = project_url),
             "https://app.crunch.io/api/datasets/",
-            '{"element":"shoji:entity","body":{"name":"Bam!"}}'
+            '{"element":"shoji:entity","body":{"name":"Bam!","project":"', project_url, '"}}'
         )
     })
 
@@ -197,11 +200,72 @@ with_mock_crunch({
 
     test_that("newExampleDataset", {
         expect_POST(
-            newExampleDataset(),
+            newExampleDataset(project = project_url),
             "https://app.crunch.io/api/datasets/",
             '{"element":"shoji:entity","body":{"name":"Example dataset",'
         )
     })
+
+    test_that("newDataset project - It can take a ProjectFolder argument", {
+        expect_POST(
+            createDataset(name = "Foo", project = projects()[["Project One"]]),
+            "https://app.crunch.io/api/datasets/",
+            '{"element":"shoji:entity","body":{"name":"Foo",',
+            '"project":"https://app.crunch.io/api/projects/project1/"}}'
+        )
+    })
+
+    test_that("newDataset project - It can take a URL argument", {
+        expect_POST(
+            createDataset(name = "Foo", project = "https://app.crunch.io/api/projects/project1/"),
+            "https://app.crunch.io/api/datasets/",
+            '{"element":"shoji:entity","body":{"name":"Foo",',
+            '"project":"https://app.crunch.io/api/projects/project1/"}}'
+        )
+    })
+
+    test_that("newDataset project - It can take a path argument", {
+        expect_POST(
+            createDataset(name = "Foo", project = "./Project One"),
+            "https://app.crunch.io/api/datasets/",
+            '{"element":"shoji:entity","body":{"name":"Foo",',
+            '"project":"https://app.crunch.io/api/projects/project1/"}}'
+        )
+    })
+
+    test_that("newDataset project - It gives a good error when invalid path", {
+        expect_error(
+            createDataset(name = "Foo", project = "./INVALID"),
+            "Could not get project ./INVALID because \"./INVALID\" is not a folder"
+        )
+    })
+
+    test_that("newDataset project - It gives a good error when invalid project", {
+        expect_error(
+            createDataset(name = "Foo", project = 1),
+            "project must be a `CrunchProject` object, a URL, or a path to a project from the root"
+        )
+    })
+
+    test_that("newDataset project - It fails when there's no project specified and no default", {
+        with(temp.option(crunch = list(crunch.default.project = NULL)), {
+            expect_error(
+                createDataset(name = "Foo"),
+                "No default project found in "
+            )
+        })
+    })
+
+    test_that("newDataset project - It can get the default from the environemnt", {
+        with(temp.option(crunch = list(crunch.default.project = "./Project One" )), {
+            expect_POST(
+                createDataset(name = "Foo"),
+                "https://app.crunch.io/api/datasets/",
+                '{"element":"shoji:entity","body":{"name":"Foo",',
+                '"project":"https://app.crunch.io/api/projects/project1/"}}'
+            )
+        })
+    })
 })
 
 with_test_authentication({
