@@ -1,7 +1,7 @@
 context("Variable catalog")
 
 with_mock_crunch({
-    ds <- loadDataset("test ds")
+    ds <- cachedLoadDataset("test ds")
     varcat <- allVariables(ds)
     varorder <- ordering(varcat)
     test_that("VariableCatalog instantiates from Shoji", {
@@ -31,7 +31,7 @@ with_mock_crunch({
             index(variables(ds)),
             index(varcat)[urls(ordering(varcat))]
         )
-        ds@hiddenVariables <- ds@variables[1]
+        ds@hiddenVariables <- allVariables(ds)[1]
         expect_is(variables(ds), "VariableCatalog")
         # Specific behavior of "hidden" is tested in test-hide-variables.R
         expect_identical(
@@ -49,7 +49,7 @@ with_mock_crunch({
     })
 
     test_that("private variables aren't considered active (#383)", {
-        ds@privateVariables <- ds@variables[1]
+        ds@privateVariables <- allVariables(ds)[1]
 
         expect_identical(
             urls(variables(ds)),
@@ -259,6 +259,7 @@ with_mock_crunch({
 
 with_test_authentication({
     ds <- newDataset(df)
+    ds <- forceVariableCatalog(ds) # Force variables catalog beause we're counting requests
     test_that("Can set descriptions (and doing so doesn't PUT order)", {
         with(temp.options(httpcache.log = ""), {
             expect_identical(
